==> johnny-five-0.5.95.tgz: package/parts.md <==
# Easy "Getting Started"

- [Sparkfun Inventor's Kit](https://www.sparkfun.com/products/11022)


# Parts


## Adafruit

- [Motor Shield](http://www.adafruit.com/products/81)
- [MaxSonar](https://www.adafruit.com/products/172)
- [Bumper Switch](https://www.adafruit.com/products/818)


## Amazon

- [Futuba Servo](http://www.amazon.com/Futaba-S3003-Servo-Standard/dp/B0015H2V72/ref=sr_1_1?s=toys-and-games&ie=UTF8&qid=1345046435&sr=1-1&keywords=futaba+servo)
- [Hitec HS322HD Servo](http://www.amazon.com/Hitec-33322S-HS-322HD-Standard-Karbonite/dp/B0006O3XEA/ref=sr_1_cc_2?s=aps&ie=UTF8&qid=1345046396&sr=1-2-catcorr&keywords=hitec+servo)
- [OSEPP I2C Expansion Shield](http://www.amazon.com/OSEPP-Expansion-Schield-Arduino-Compatible/dp/B007JBUL0C/ref=sr_1_10?s=electronics&ie=UTF8&qid=1345046344&sr=1-10&keywords=i2c+shield)
- [SainSmart Sensor Shield](http://www.amazon.com/SainSmart-Sensor-Digital-Arduino-Duemilanove/dp/B006TQ314G)


## DFRobot

- [Analog Slide Position Sensor](http://www.dfrobot.com/index.php?route=product/product&filter_name=slide&product_id=131)
- [I2C/TWI LCD1602 Module](http://www.dfrobot.com/index.php?route=product/product&filter_name=i2c/twi&product_id=135)
- [DFRobot LG-NS Gripper](http://www.dfrobot.com/index.php?route=product/product&filter_name=gripper&product_id=628#.UCvGymNST_k)


## Makershed

- [Getting Started with Arduino](http://www.makershed.com/Getting_Started_with_Arduino_Kit_V3_0_p/msgsa.htm)
- [Ultimate Microcontroller Pack](http://www.makershed.com/Ultimate_Microcontroller_Pack_p/msump.htm)

## Maxbotix

- **[XL-MaxSonar EZ/AE (MB1230)](http://www.maxbotix.com/products/XL-EZ.htm)**
- [LV-MaxSonar EZ1 (MB1230)](http://www.maxbotix.com/products/LV.htm)

## Parallax

- **[Robot Base](http://www.parallax.com/Store/Education/KitsandBoards/tabid/182/ProductID/820/List/0/Default.aspx?SortField=ProductName,ProductName)**
- [2 Axis Joystick](http://www.parallax.com/Store/Sensors/PressureFlexRPM/tabid/177/ProductID/581/List/0/Default.aspx?SortField=ProductName,ProductName)
- [5 Position Switch](http://www.parallax.com/Store/Sensors/PressureFlexRPM/tabid/177/ProductID/615/List/0/Default.aspx?SortField=ProductName,ProductName)
- [Gripper Kit](http://www.parallax.com/StoreSearchResults/tabid/768/txtSearch/clamp/List/0/SortField/4/ProductID/311/Default.aspx)
- [PMB-648 GPS SiRF Internal Antenna](http://www.parallax.com/Store/Microcontrollers/BASICStampModules/tabid/134/txtSearch/gps/List/1/ProductID/644/Default.aspx?SortField=ProductName%2cProductName)
- [Ping)))](http://www.parallax.com/Store/Sensors/ObjectDetection/tabid/176/ProductID/92/List/0/Default.aspx?SortField=ProductName,ProductName)
- [PIR](http://www.parallax.com/Store/Sensors/ObjectDetection/tabid/176/ProductID/83/List/0/Default.aspx?SortField=ProductName,ProductName)
- [Standard Servo](http://www.parallax.com/Store/Accessories/MotorServos/tabid/163/ProductID/101/List/0/Default.aspx?SortField=ProductName,ProductName)
- [Continuous Servo](http://www.parallax.com/Store/Robots/RoboticComponents/tabid/198/List/0/ProductID/102/Default.aspx?SortField=ProductName%2cProductName)
- [Tank Tread Kit](http://www.parallax.com/Store/Robots/RoboticAccessories/tabid/145/ProductID/78/List/0/Default.aspx?SortField=ProductName,ProductName)


## Sparkfun


- [Arcade Joystick](http://www.sparkfun.com/products/9136)
- [Laser Card Module - Red](http://www.sparkfun.com/products/594)
- [Pan/Tilt Bracket](http://www.sparkfun.com/products/10335)
- [Robotic Claw](http://www.sparkfun.com/products/10332)
- [Robotic Claw Pan/Tilt Bracket](http://www.sparkfun.com/products/10826)
- [Servo Extension Cable - Female to Female (shrouded)](http://www.sparkfun.com/products/8738)
- [Servo Cable - Female to Female](http://www.sparkfun.com/products/9187)
- [Servo - Medium](http://www.sparkfun.com/products/10333)
- [Servo - Medium Full Rotation](http://www.sparkfun.com/products/10189)
- [Servo - Small](http://www.sparkfun.com/products/9065)

- [SoftPot Membrane Potentiometer - 50mm](http://www.sparkfun.com/products/8680)
- [Wiper/Actuator - 1N to 3N Force](http://www.sparkfun.com/products/9075)



# Tools

- [LadyAda's Toolkit](https://www.adafruit.com/products/136) (I don't have this, but it's basically the same as all of the tools I have)


- [Panavise Vaccuum Base stand](http://www.amazon.com/PanaVise-209-Vacuum-Base-Jr/dp/B000CONJUM/ref=sr_1_3?ie=UTF8&qid=1345046483&sr=8-3&keywords=panavise)
- [Panavise Junior](http://www.amazon.com/PanaVise-Model-201-Junior-Miniature/dp/B000B61D22/ref=sr_1_1?ie=UTF8&qid=1345046483&sr=8-1&keywords=panavise)

==> johnny-five-0.7.42.tgz: package/parts.md <==
# Easy "Getting Started"

- [Sparkfun Inventor's Kit](https://www.sparkfun.com/products/11022)


# Parts


## Adafruit

- [Triple-Axis Accelerometer, ADXL326](http://www.adafruit.com/products/1018)
- [Motor Shield](http://www.adafruit.com/products/81)
- [MaxSonar](https://www.adafruit.com/products/172)
- [Bumper Switch](https://www.adafruit.com/products/818)


## Amazon

- [Futuba Servo](http://www.amazon.com/Futaba-S3003-Servo-Standard/dp/B0015H2V72/ref=sr_1_1?s=toys-and-games&ie=UTF8&qid=1345046435&sr=1-1&keywords=futaba+servo)
- [Hitec HS322HD Servo](http://www.amazon.com/Hitec-33322S-HS-322HD-Standard-Karbonite/dp/B0006O3XEA/ref=sr_1_cc_2?s=aps&ie=UTF8&qid=1345046396&sr=1-2-catcorr&keywords=hitec+servo)
- [OSEPP I2C Expansion Shield](http://www.amazon.com/OSEPP-Expansion-Schield-Arduino-Compatible/dp/B007JBUL0C/ref=sr_1_10?s=electronics&ie=UTF8&qid=1345046344&sr=1-10&keywords=i2c+shield)
- [SainSmart Sensor Shield](http://www.amazon.com/SainSmart-Sensor-Digital-Arduino-Duemilanove/dp/B006TQ314G)


## DFRobot

- [Analog Slide Position Sensor](http://www.dfrobot.com/index.php?route=product/product&filter_name=slide&product_id=131)
- [I2C/TWI LCD1602 Module](http://www.dfrobot.com/index.php?route=product/product&filter_name=i2c/twi&product_id=135)
- [DFRobot LG-NS Gripper](http://www.dfrobot.com/index.php?route=product/product&filter_name=gripper&product_id=628#.UCvGymNST_k)


## Makershed

- [Getting Started with Arduino](http://www.makershed.com/Getting_Started_with_Arduino_Kit_V3_0_p/msgsa.htm)
- [Ultimate Microcontroller Pack](http://www.makershed.com/Ultimate_Microcontroller_Pack_p/msump.htm)

## Maxbotix

- **[XL-MaxSonar EZ/AE (MB1230)](http://www.maxbotix.com/products/XL-EZ.htm)**
- [LV-MaxSonar EZ1 (MB1230)](http://www.maxbotix.com/products/LV.htm)

## Parallax

- **[Robot Base](http://www.parallax.com/Store/Education/KitsandBoards/tabid/182/ProductID/820/List/0/Default.aspx?SortField=ProductName,ProductName)**
- [2 Axis Joystick](http://www.parallax.com/Store/Sensors/PressureFlexRPM/tabid/177/ProductID/581/List/0/Default.aspx?SortField=ProductName,ProductName)
- [5 Position Switch](http://www.parallax.com/Store/Sensors/PressureFlexRPM/tabid/177/ProductID/615/List/0/Default.aspx?SortField=ProductName,ProductName)
- [Gripper Kit](http://www.parallax.com/StoreSearchResults/tabid/768/txtSearch/clamp/List/0/SortField/4/ProductID/311/Default.aspx)
- [PMB-648 GPS SiRF Internal Antenna](http://www.parallax.com/Store/Microcontrollers/BASICStampModules/tabid/134/txtSearch/gps/List/1/ProductID/644/Default.aspx?SortField=ProductName%2cProductName)
- [Ping)))](http://www.parallax.com/Store/Sensors/ObjectDetection/tabid/176/ProductID/92/List/0/Default.aspx?SortField=ProductName,ProductName)
- [PIR](http://www.parallax.com/Store/Sensors/ObjectDetection/tabid/176/ProductID/83/List/0/Default.aspx?SortField=ProductName,ProductName)
- [Standard Servo](http://www.parallax.com/Store/Accessories/MotorServos/tabid/163/ProductID/101/List/0/Default.aspx?SortField=ProductName,ProductName)
- [Continuous Servo](http://www.parallax.com/Store/Robots/RoboticComponents/tabid/198/List/0/ProductID/102/Default.aspx?SortField=ProductName%2cProductName)
- [Tank Tread Kit](http://www.parallax.com/Store/Robots/RoboticAccessories/tabid/145/ProductID/78/List/0/Default.aspx?SortField=ProductName,ProductName)


## Sparkfun


- [Triple Axis Accelerometer, MMA7361](https://www.sparkfun.com/products/9652)
- [Arcade Joystick](http://www.sparkfun.com/products/9136)
- [Laser Card Module - Red](http://www.sparkfun.com/products/594)
- [Pan/Tilt Bracket](http://www.sparkfun.com/products/10335)
- [Robotic Claw](http://www.sparkfun.com/products/10332)
- [Robotic Claw Pan/Tilt Bracket](http://www.sparkfun.com/products/10826)
- [Servo Extension Cable - Female to Female (shrouded)](http://www.sparkfun.com/products/8738)
- [Servo Cable - Female to Female](http://www.sparkfun.com/products/9187)
- [Servo - Medium](http://www.sparkfun.com/products/10333)
- [Servo - Medium Full Rotation](http://www.sparkfun.com/products/10189)
- [Servo - Small](http://www.sparkfun.com/products/9065)
- [SoftPot Membrane - 50mm](http://www.sparkfun.com/products/8680)
- [Triple Axis Magnometer/Compass HMC5883L](https://www.sparkfun.com/products/10530)
- [Wiper/Actuator - 1N to 3N Force](http://www.sparkfun.com/products/9075)



# Tools

- [LadyAda's Toolkit](https://www.adafruit.com/products/136) (I don't have this, but it's basically the same as all of the tools I have)
- [Panavise Vaccuum Base stand](http://www.amazon.com/PanaVise-209-Vacuum-Base-Jr/dp/B000CONJUM/ref=sr_1_3?ie=UTF8&qid=1345046483&sr=8-3&keywords=panavise)
- [Panavise Junior](http://www.amazon.com/PanaVise-Model-201-Junior-Miniature/dp/B000B61D22/ref=sr_1_1?ie=UTF8&qid=1345046483&sr=8-1&keywords=panavise)
